summaryrefslogtreecommitdiff
path: root/ace/Thread_Manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'ace/Thread_Manager.h')
-rw-r--r--ace/Thread_Manager.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/ace/Thread_Manager.h b/ace/Thread_Manager.h
index 74595235013..bf459052e2d 100644
--- a/ace/Thread_Manager.h
+++ b/ace/Thread_Manager.h
@@ -373,12 +373,12 @@ public:
// register the thread with the Thread_Manager.
~ACE_Thread_Control (void);
- // Implicitly kill the thread on exit and remove it from its
- // associated ThreadManager.
+ // Remove the thread from its associated <Thread_Manager> and exit
+ // the thread if <do_thr_exit> is enabled.
- void *exit (void *status);
- // Explicitly kill the thread on exit and remove it from its
- // associated <Thread_Manager>.
+ void *exit (void *status, int do_thr_exit);
+ // Remove this thread from its associated <Thread_Manager> and exit
+ // the thread if <do_thr_exit> is enabled.
int insert (ACE_Thread_Manager *tm);
// Store the <Thread_Manager> and use it to register ourselves for